@@ -25,19 +25,24 @@ import logging
 import os
 import pathlib
 import sys
-from typing import TYPE_CHECKING, Set, Type
+from typing import TYPE_CHECKING, List, Set, Type
+
+from rich.console import Console
+from rich.markdown import Markdown
 
 from ansiblelint import cli, formatters
-from ansiblelint.constants import DEFAULT_RULESDIR
 from ansiblelint.generate_docs import rules_as_rst
 from ansiblelint.rules import RulesCollection
 from ansiblelint.runner import Runner
-from ansiblelint.utils import get_playbooks_and_roles
+from ansiblelint.utils import get_playbooks_and_roles, get_rules_dirs
 
 if TYPE_CHECKING:
     from argparse import Namespace
 
+    from ansiblelint.errors import MatchError
+
 _logger = logging.getLogger(__name__)
+console = Console()
 
 
 def initialize_logger(level: int = 0) -> None:
@@ -74,6 +79,33 @@ def choose_formatter_factory(
     return r
 
 
+def report_outcome(matches: List["MatchError"], options) -> int:
+    """Display information about how to skip found rules.
+
+    Returns exit code, 2 if erros were found, 0 when only warnings were found.
+    """
+    failure = False
+    msg = """\
+You can skip specific rules by adding them to the skip_list section of your configuration file:
+```yaml
+# .ansible-lint
+warn_list:  # or 'skip_list' to silence them completely
+"""
+    matched_rules = {match.rule.id: match.rule.shortdesc for match in matches}
+    for id in sorted(matched_rules.keys()):
+        if id not in options.warn_list:
+            msg += f"  - '{id}'  # {matched_rules[id]}'\n"
+            failure = True
+    msg += "```"
+
+    if failure:
+        if not options.quiet and not options.parseable:
+            console.print(Markdown(msg))
+        return 2
+    else:
+        return 0
+
+
 def main() -> int:
     """Linter CLI entry point."""
     cwd = pathlib.Path.cwd()
@@ -86,10 +118,8 @@ def main() -> int:
     formatter_factory = choose_formatter_factory(options)
     formatter = formatter_factory(cwd, options.display_relative_path)
 
-    if options.use_default_rules:
-        rulesdirs = options.rulesdir + [DEFAULT_RULESDIR]
-    else:
-        rulesdirs = options.rulesdir or [DEFAULT_RULESDIR]
+    rulesdirs = get_rules_dirs([str(rdir) for rdir in options.rulesdir],
+                               options.use_default_rules)
     rules = RulesCollection(rulesdirs)
 
     if options.listrules:
@@ -136,7 +166,7 @@ def main() -> int:
             print(formatter.format(match))
 
     if matches:
-        return 2
+        return report_outcome(matches, options=options)
     else:
         return 0
 
