@@ -1,9 +1,4 @@
-import unittest
-import os
-
-from ansiblelint import RulesCollection
-from test import RunFromText
-
+import pytest
 
 ROLE_TASKS = '''
 ---
@@ -13,36 +8,30 @@ ROLE_TASKS = '''
 - name: test 303 (skipped)
   command: git log # noqa 303
   changed_when: False
+'''
 
-- name: test 401 and 501
-  become_user: alice
-  action: git
-- name: test 401 and 501 (skipped)  # noqa 401 501
-  become_user: alice
-  action: git
-- name: test 401 and 501 (skipped via skip_ansible_lint)
-  become_user: alice
-  action: git
-  tags:
-    skip_ansible_lint
-
-- name: test 601
-  debug:
-    msg: testing
-  when: my_var == true
-- name: test 601 (skipped)
-  debug:
-    msg: testing
-  when: my_var == true  # noqa 601
-
-- name: test 303
-  command: git log
-  changed_when: False
-- name: test 303 (skipped via no warn)
-  command: git log
-  args:
-    warn: False
-  changed_when: False
+ROLE_TASKS_WITH_BLOCK = '''
+---
+- name: bad git 1  # noqa 401
+  action: git a=b c=d
+- name: bad git 2
+  action: git a=b c=d
+- name: Block with rescue and always section
+  block:
+    - name: bad git 3  # noqa 401
+      action: git a=b c=d
+    - name: bad git 4
+      action: git a=b c=d
+  rescue:
+    - name: bad git 5  # noqa 401
+      action: git a=b c=d
+    - name: bad git 6
+      action: git a=b c=d
+  always:
+    - name: bad git 7  # noqa 401
+      action: git a=b c=d
+    - name: bad git 8
+      action: git a=b c=d
 '''
 
 PLAYBOOK = '''
@@ -93,22 +82,41 @@ galaxy_info:  # noqa 701
   license: MIT
 '''
 
+ROLE_TASKS_WITH_BLOCK_BECOME = '''
+- hosts:
+  tasks:
+    - name: foo
+      become: true
+      block:
+        - name: bar
+          become_user: jonhdaa
+          command: "/etc/test.sh"
+'''
 
-class TestSkipInsideYaml(unittest.TestCase):
-    rulesdir = os.path.join('lib', 'ansiblelint', 'rules')
-    collection = RulesCollection.create_from_directory(rulesdir)
 
-    def setUp(self):
-        self.runner = RunFromText(self.collection)
+def test_role_tasks(default_text_runner):
+    results = default_text_runner.run_role_tasks_main(ROLE_TASKS)
+    assert len(results) == 1
 
-    def test_role_tasks(self):
-        results = self.runner.run_role_tasks_main(ROLE_TASKS)
-        self.assertEqual(5, len(results))
 
-    def test_playbook(self):
-        results = self.runner.run_playbook(PLAYBOOK)
-        self.assertEqual(8, len(results))
+def test_role_tasks_with_block(default_text_runner):
+    results = default_text_runner.run_role_tasks_main(ROLE_TASKS_WITH_BLOCK)
+    assert len(results) == 4
 
-    def test_role_meta(self):
-        results = self.runner.run_role_meta_main(ROLE_META)
-        self.assertEqual(0, len(results))
+
+@pytest.mark.parametrize(
+    ('playbook_src', 'results_num'),
+    (
+        (PLAYBOOK, 7),
+        (ROLE_TASKS_WITH_BLOCK_BECOME, 0),
+    ),
+    ids=('generic', 'with block become inheritance'),
+)
+def test_playbook(default_text_runner, playbook_src, results_num):
+    results = default_text_runner.run_playbook(playbook_src)
+    assert len(results) == results_num
+
+
+def test_role_meta(default_text_runner):
+    results = default_text_runner.run_role_meta_main(ROLE_META)
+    assert len(results) == 0
